# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import pulumi
import pulumi.runtime
from . import utilities, tables

class Network(pulumi.CustomResource):
    """
    Manages a Docker Network. This can be used alongside
    [docker\_container](https://www.terraform.io/docs/providers/docker/r/container.html)
    to create virtual networks within the docker environment.
    """
    def __init__(__self__, __name__, __opts__=None, attachable=None, check_duplicate=None, driver=None, ingress=None, internal=None, ipam_configs=None, ipam_driver=None, ipv6=None, labels=None, name=None, options=None):
        """Create a Network resource with the given unique name, props, and options."""
        if not __name__:
            raise TypeError('Missing resource name argument (for URN creation)')
        if not isinstance(__name__, str):
            raise TypeError('Expected resource name to be a string')
        if __opts__ and not isinstance(__opts__, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')

        __props__ = dict()

        __props__['attachable'] = attachable

        __props__['check_duplicate'] = check_duplicate

        __props__['driver'] = driver

        __props__['ingress'] = ingress

        __props__['internal'] = internal

        __props__['ipam_configs'] = ipam_configs

        __props__['ipam_driver'] = ipam_driver

        __props__['ipv6'] = ipv6

        __props__['labels'] = labels

        __props__['name'] = name

        __props__['options'] = options

        __props__['scope'] = None

        super(Network, __self__).__init__(
            'docker:index/network:Network',
            __name__,
            __props__,
            __opts__)


    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import pulumi
import pulumi.runtime
from .. import utilities, tables

__config__ = pulumi.Config('docker')

ca_material = __config__.get('caMaterial') or utilities.get_env('DOCKER_CA_MATERIAL')
"""
PEM-encoded content of Docker host CA certificate
"""

cert_material = __config__.get('certMaterial') or utilities.get_env('DOCKER_CERT_MATERIAL')
"""
PEM-encoded content of Docker client certificate
"""

cert_path = __config__.get('certPath') or utilities.get_env('DOCKER_CERT_PATH')
"""
Path to directory with Docker TLS config
"""

host = utilities.require_with_default(lambda: __config__.require('host'), (utilities.get_env('DOCKER_HOST') or 'unix:///var/run/docker.sock'))
"""
The Docker daemon address
"""

key_material = __config__.get('keyMaterial') or utilities.get_env('DOCKER_KEY_MATERIAL')
"""
PEM-encoded content of Docker client private key
"""

registry_auth = __config__.get('registryAuth')




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import pulumi
import pulumi.runtime
from . import utilities, tables

class Container(pulumi.CustomResource):
    """
    Manages the lifecycle of a Docker container.
    """
    def __init__(__self__, __name__, __opts__=None, attach=None, capabilities=None, command=None, cpu_set=None, cpu_shares=None, destroy_grace_seconds=None, devices=None, dns=None, dns_opts=None, dns_searches=None, domainname=None, entrypoints=None, envs=None, healthcheck=None, hosts=None, hostname=None, image=None, labels=None, links=None, log_driver=None, log_opts=None, logs=None, max_retry_count=None, memory=None, memory_swap=None, must_run=None, name=None, network_aliases=None, network_mode=None, networks=None, networks_advanced=None, pid_mode=None, ports=None, privileged=None, publish_all_ports=None, restart=None, rm=None, start=None, ulimits=None, uploads=None, user=None, userns_mode=None, volumes=None):
        """Create a Container resource with the given unique name, props, and options."""
        if not __name__:
            raise TypeError('Missing resource name argument (for URN creation)')
        if not isinstance(__name__, str):
            raise TypeError('Expected resource name to be a string')
        if __opts__ and not isinstance(__opts__, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')

        __props__ = dict()

        __props__['attach'] = attach

        __props__['capabilities'] = capabilities

        __props__['command'] = command

        __props__['cpu_set'] = cpu_set

        __props__['cpu_shares'] = cpu_shares

        __props__['destroy_grace_seconds'] = destroy_grace_seconds

        __props__['devices'] = devices

        __props__['dns'] = dns

        __props__['dns_opts'] = dns_opts

        __props__['dns_searches'] = dns_searches

        __props__['domainname'] = domainname

        __props__['entrypoints'] = entrypoints

        __props__['envs'] = envs

        __props__['healthcheck'] = healthcheck

        __props__['hosts'] = hosts

        __props__['hostname'] = hostname

        if not image:
            raise TypeError('Missing required property image')
        __props__['image'] = image

        __props__['labels'] = labels

        __props__['links'] = links

        __props__['log_driver'] = log_driver

        __props__['log_opts'] = log_opts

        __props__['logs'] = logs

        __props__['max_retry_count'] = max_retry_count

        __props__['memory'] = memory

        __props__['memory_swap'] = memory_swap

        __props__['must_run'] = must_run

        __props__['name'] = name

        __props__['network_aliases'] = network_aliases

        __props__['network_mode'] = network_mode

        __props__['networks'] = networks

        __props__['networks_advanced'] = networks_advanced

        __props__['pid_mode'] = pid_mode

        __props__['ports'] = ports

        __props__['privileged'] = privileged

        __props__['publish_all_ports'] = publish_all_ports

        __props__['restart'] = restart

        __props__['rm'] = rm

        __props__['start'] = start

        __props__['ulimits'] = ulimits

        __props__['uploads'] = uploads

        __props__['user'] = user

        __props__['userns_mode'] = userns_mode

        __props__['volumes'] = volumes

        __props__['bridge'] = None
        __props__['container_logs'] = None
        __props__['exit_code'] = None
        __props__['gateway'] = None
        __props__['ip_address'] = None
        __props__['ip_prefix_length'] = None
        __props__['network_datas'] = None

        super(Container, __self__).__init__(
            'docker:index/container:Container',
            __name__,
            __props__,
            __opts__)


    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import pulumi
import pulumi.runtime
from . import utilities, tables

class Volume(pulumi.CustomResource):
    """
    Creates and destroys a volume in Docker. This can be used alongside
    [docker\_container](https://www.terraform.io/docs/providers/docker/r/container.html)
    to prepare volumes that can be shared across containers.
    """
    def __init__(__self__, __name__, __opts__=None, driver=None, driver_opts=None, labels=None, name=None):
        """Create a Volume resource with the given unique name, props, and options."""
        if not __name__:
            raise TypeError('Missing resource name argument (for URN creation)')
        if not isinstance(__name__, str):
            raise TypeError('Expected resource name to be a string')
        if __opts__ and not isinstance(__opts__, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')

        __props__ = dict()

        __props__['driver'] = driver

        __props__['driver_opts'] = driver_opts

        __props__['labels'] = labels

        __props__['name'] = name

        __props__['mountpoint'] = None

        super(Volume, __self__).__init__(
            'docker:index/volume:Volume',
            __name__,
            __props__,
            __opts__)


    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop

